Variables and types
:::::::::::::::::::::::

.. toctree::
   :maxdepth: 3

   MoreOutput.rst
   Values.rst
   Variables.rst
   Assignment.rst
   OutputtingVariables.rst
   Keywords.rst
   Operators.rst
   OrderofOperations.rst
   OperatorsforCharacters.rst
   Composition.rst
   Glossary.rst
   Exercises.rst
   mixedUpCode.rst
   activeCode.rst
